/*
 * Copyright (C) 2004-2006 Jimmy Do <crispyleaves@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
#ifndef START_TIMER_DIALOG_H
#define START_TIMER_DIALOG_H
#include <gtk/gtk.h>
#include "timer-applet.h"

G_BEGIN_DECLS

void
start_timer_dialog_create (TimerApplet *timer_applet);
void
start_timer_dialog_open (TimerApplet *timer_applet);
void
start_timer_dialog_open_with_name_and_duration (TimerApplet *timer_applet, const gchar *timer_name, guint timer_duration);

G_END_DECLS

#endif /* START_TIMER_DIALOG_H */
